@@ -212,11 +212,33 @@ class GalacticComponent(object):
         """
         raise NotImplementedError
 
-    def plot_countours():
+    def plot_countours(self, rmin=0.5, rmax=10000, zmin=-2000, zmax=2000, npoints=1000, log=False, grid=None, cmap='cividis'):
         """
         plot contours of density in cylindrical coordinates
         """
-        raise NotImplementedError
+        import matplotlib.pyplot as plt
+        from .plot_style import  plot_style
+        plot_style()
+
+        rs= np.linspace(rmin,rmax, npoints)
+        zs= np.linspace(zmin,zmax, npoints)
+
+        if grid is None:
+            grid = np.meshgrid(rs, zs)
+
+        dens=self.stellar_density(grid[0], grid[1])
+
+        if log:
+            dens=np.log(self.stellar_density(grid[0], grid[1]))
+        
+        fig, ax=plt.subplots()
+
+        h = plt.contourf(rs, zs, dens, cmap=cmap)
+        h = plt.contour(rs, zs, dens, cmap= 'cubehelix')
+
+        ax.set(xlabel='r (pc)', ylabel='z (pc)')
+        return ax
+
 
 
 class Disk(GalacticComponent):
