@@ -7,9 +7,31 @@ from .core_tools import *
 from .relations import teff_to_spt_subdwarf
 import seaborn as sns
 
-POLYNOMIALS=np.load(DATA_FOLDER+'/abs_mag_relations.npy', allow_pickle=True)[0]
 
 class Population(object):
+    """
+    Class for a poulation
+
+    Attributes:
+    ----
+        x_grid: grid of values ( array)
+        cdf:  corresponding values from the CDF
+        nsample: optional, number of samples
+
+    Properties:
+    -------
+        random draws
+
+    Methods:
+    --------
+
+    Example:
+    -------
+        > x = np.arange(0, 10)
+        > cdf = x**3/(x[-1]**3)
+        > res= random_draw(x, cdf)
+
+    """
     def __init__(self, **kwargs):
         self.imfpower= kwargs.get('imf_power', -0.6)
         self.binaryfraction= kwargs.get('binary_fraction', 0.2)
@@ -73,7 +95,11 @@ class Population(object):
 
         #compute combined binary spectral types
         xy=np.vstack([np.round(np.array(spt_primar), decimals=0), np.round(np.array(spt_second), decimals=0)]).T
-        spt_binr=get_system_type(xy[:,0], xy[:,1], read_bintemplates())
+        spt_binr=np.array(get_system_type(xy[:,0], xy[:,1])).astype(float)
+        #Remember to assign <15 or >39 primary to primary and 
+        out_range=np.logical_or(xy[:,0] < 15, xy[:,0] > 39)
+        #print (spt_binr[out_range])
+        spt_binr[out_range]=xy[:,0][out_range]
 
 
         values={ 'sing_evol': single_evol, 'sing_spt':spts_singl,
@@ -82,16 +108,26 @@ class Population(object):
                     'binary_spt': spt_binr }
 
         #make systems
-        return make_systems(values, self.binaryfraction)
+        return _make_systems(values, self.binaryfraction)
 
     @staticmethod
-    def visualize(final_df, keys=['mass', 'age', 'spt']):
-        g = sns.PairGrid(final_df[keys] , diag_sharey=False, corner=True)
+    def visualize(df, keys=['mass', 'age', 'spt']):
+        import matplotlib.pyplot as plt
+        g = sns.PairGrid(df[keys] , diag_sharey=False, corner=True)
         g.map_diag(plt.hist, log=True, bins=32)
         g.map_offdiag(sns.scatterplot, size=0.1, color='k', alpha=0.1)
 
+    def add_kinematics():
+        raise NotImplementedError
 
-def make_systems(mods, bfraction):
+    def addd_distances():
+        raise NotImplementedError
+
+    def add_magnitudes():
+        raise NotImplementedError
+
+
+def _make_systems(mods, bfraction):
     """
     """
     
@@ -157,7 +193,9 @@ def make_systems(mods, bfraction):
 def pop_mags(x, d=None, keys=[], object_type='dwarfs', get_from='spt', reference=None, pol=None):
     """
     Compute magnitudes from pre-computed absolute mag relations
+
     """
+    from .abs_mag_relations import POLYNOMIALS
     res={}
     if pol is None: pol=POLYNOMIALS['absmags_{}'.format(get_from)][object_type]
     if reference is not None: pol=POLYNOMIALS['references'][reference]
@@ -167,7 +205,7 @@ def pop_mags(x, d=None, keys=[], object_type='dwarfs', get_from='spt', reference
         if k not in pol.keys():
             warnings.warn("{} relation not available for {} ".format(k,object_type))
 
-        fit=pol[k]['fit']
+        fit=np.poly1d(pol[k]['fit'])
         scat=pol[k]['scatter']
         #print (k, 'scatter', scat)
         rng=pol[k]['range']
@@ -192,6 +230,7 @@ def pop_colors(x, d=None, keys=[], object_type='dwarfs', get_from='spt', referen
     """
     Compute colors from pre-computed absolute mag relations
     """
+    from .abs_mag_relations import POLYNOMIALS
     res={}
     if pol is None: pol=POLYNOMIALS['colors_{}'.format(get_from)][object_type]
     if reference is not None: pol=POLYNOMIALS['references'][reference]
@@ -201,7 +240,7 @@ def pop_colors(x, d=None, keys=[], object_type='dwarfs', get_from='spt', referen
             warnings.warn("{} relation not available for {} ".format(k,object_type))
 
         #if pol[k]['method']=='polynmial':
-        fit=pol[k]['fit']
+        fit=np.poly1d(pol[k]['fit'])
         #if pol[k]['method']=='spline':
         #     fit=pol[k]['fit']
 
@@ -280,6 +319,7 @@ def simulate_population(disk, coord, dmin, dmax, nsample=1e5, poptype='dwarfs',
 def pop_mags_from_color(color, d=None, keys=[], object_type='dwarfs'):
     """
     """
+    from .abs_mag_relations import POLYNOMIALS
     res={}
     for k in tqdm(keys):
         pol=POLYNOMIALS['colors'][object_type]
@@ -297,6 +337,7 @@ def pop_mags_from_color(color, d=None, keys=[], object_type='dwarfs'):
     return pd.DataFrame(res)
 
 def compute_vols_and_numbers(df, disk, tdisk, halo, sptgrid, footprint, maglimits):
+    from .abs_mag_relations import POLYNOMIALS
     counts={}
     vols={}
     dists={}
